@@ -14,6 +14,8 @@ GetParamsType = T.TypeVar("GetParamsType", bound=Params)
 QueryParamsType = T.TypeVar("QueryParamsType", bound=Params)
 EdgesType = T.TypeVar("EdgesType", bound=BaseModel)
 
+ResolverType = T.TypeVar("ResolverType", bound="Resolver")
+
 
 class Resolver(BaseModel, T.Generic[NodeType]):
     node: T.ClassVar[T.Type[NodeType]]
@@ -130,6 +132,28 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             return self.parse_obj_nested(obj)
         return None
 
+    @staticmethod
+    def resolvers_by_typename() -> T.Dict[str, T.Type[Resolver]]:
+        d = {}
+        subs = Resolver.__subclasses__()
+        for sub in subs:
+            typename = sub.node.Dgraph.typename
+            if typename in d:
+                raise GQLException(
+                    f"Two Resolvers share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
+                )
+            d[typename] = sub
+        return d
+
+    @classmethod
+    def from_gql_query_str(
+        cls: ResolverType, gql_str: str, path: T.List[str]
+    ) -> ResolverType:
+        """ find the nested and use that """
+        """{name age is_friends_with {name}}"""
+        edge_names = cls.edges.__fields__.keys()
+        ...
+
     """
     def get(self, get_params: GetParamsType) -> T.Optional[NodeType]:
         return self._get(kwargs_d=get_params.dict())
@@ -143,16 +167,3 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             raise GQLException(f"Node with {get_params=} was None")
         return node
     """
-
-    @staticmethod
-    def resolvers_by_typename() -> T.Dict[str, T.Type[Resolver]]:
-        d = {}
-        subs = Resolver.__subclasses__()
-        for sub in subs:
-            typename = sub.node.Dgraph.typename
-            if typename in d:
-                raise GQLException(
-                    f"Two Resolvers share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
-                )
-            d[typename] = sub
-        return d
